#!/usr/bin/env python

import sys
import pygtk
pygtk.require("2.0")
import gtk
import gtk.glade
import commands
import os
import gettext
from user import home
import webkit
import string

CONFIG_LOCATION = home + '/.fuduntu/elmer-welcome/'
FLAG_LOCATION = CONFIG_LOCATION + 'norun.flag'
LIB_LOCATION = '/usr/lib/elmer-welcome/'


class MintWelcome(object):
	def __init__(self):
		gladefile = LIB_LOCATION + "elmer-welcome.glade"
		wTree = gtk.glade.XML(gladefile,"main_window")
		wTree.get_widget("main_window").set_title("Welcome to Fuduntu")
		wTree.get_widget("main_window").set_icon_from_file("/usr/share/icons/fuduntu/48x48/places/start-here.png")	

		from configobj import ConfigObj
		config = ConfigObj("/etc/sysconf/elmer.conf")
		description = config['DESCRIPTION']
		codename = config['CODENAME']
		edition = config['EDITION']
		release = config['RELEASE']
		description = description.replace("\"", "")
		self.release_notes = config['RELEASE_NOTES_URL']
		self.user_guide = config['USER_GUIDE_URL']
		self.new_features = config['NEW_FEATURES_URL']
	
		wTree.get_widget("main_window").connect("destroy", gtk.main_quit)	

		browser = webkit.WebView()
		wTree.get_widget("scrolled_welcome").add(browser)
		browser.connect("button-press-event", lambda w, e: e.button == 3)
		subs = {}
		subs['release'] = release + " (" + codename + ")"
		subs['edition'] = edition
		subs['title'] = "Welcome to Fuduntu"
		subs['release_title'] = "Release"
		subs['edition_title'] = "Edition"
		subs['discover_title'] = "Documentation"
		subs['find_help_title'] = "Support"
		subs['contribute_title'] = "Project"
		subs['community_title'] = "Community"
		subs['new_features'] = "Release Notes"
		subs['know_problems'] = "Known Issues"
		subs['user_guide'] = "Users Guide (Wiki)"
		subs['forums'] = "Forums"
		subs['irc'] = "Live Chat (IRC)"
		subs['donation'] = "Donations"
		subs['get_involved'] = "How to get involved"
		subs['facebook'] = "Facebook"
                subs['plus'] = "Google Plus"
                subs['twitter'] = "Twitter"
		subs['blog'] = "Blog"
		subs['tutorials'] = "Getting Started"
		subs['show'] = "Show this dialog at startup"
		subs['close'] = "Close"
		if os.path.exists(FLAG_LOCATION):		
			subs['checked'] = ("")
		else:
			subs['checked'] = ("CHECKED")

		subs['welcome'] = ("Welcome to Fuduntu. We hope you enjoy your stay as much as we did making it!")
		
		template = open(LIB_LOCATION + "templates/welcome.html").read()		
		html = string.Template(template).safe_substitute(subs)
		browser.load_html_string(html, "file:/")	
		browser.connect('title-changed', self.title_changed)
		wTree.get_widget("main_window").show_all()

	def title_changed(self, view, frame, title):	
		if title.startswith("nop"):
		    return
		# call directive looks like:
		#  "call:func:arg1,arg2"
		#  "call:func"
		if title == "event_irc":
			os.system("xdg-open http://fuduntu.org/irc.html")
		elif title == "event_new_features":
			os.system("xdg-open " + self.new_features)
		elif title == "event_known_problems":
			os.system("xdg-open " + self.release_notes)
		elif title == "event_user_guide":
			os.system("xdg-open " + self.user_guide)
		elif title == "event_forums":
			os.system("xdg-open http://fuduntu.org/forum")
		elif title == "event_tutorials":
			os.system("xdg-open http://fuduntu.org/wiki/index.php/Getting_Started")
		elif title == "event_facebook":
			os.system("xdg-open http://www.facebook.com/fuduntu")
		elif title == "event_plus":
			os.system("xdg-open https://plus.google.com/b/113644080780903084842/113644080780903084842/posts")
                elif title == "event_twitter":
                        os.system("xdg-open https://twitter.com/Fuduntu")
		elif title == "event_blog":
			os.system("xdg-open http://fuduntu.org/blog")
		elif title == "event_get_involved":
			os.system("xdg-open http://fuduntu.org/wiki/index.php/The_Fuduntu_Team#Applying_to_Intern")
		elif title == "event_donation":
			os.system("xdg-open http://fuduntu.org/donate.html")
		elif title == "event_close_true":
			if os.path.exists(FLAG_LOCATION):
				os.system("rm -rf " + FLAG_LOCATION)
			gtk.main_quit()
		elif title == "event_close_false":
			os.system("mkdir -p " + CONFIG_LOCATION)		
			os.system("touch " + FLAG_LOCATION)
			gtk.main_quit()
		elif title == "checkbox_checked":
			if os.path.exists(FLAG_LOCATION):
				os.system("rm -rf " + FLAG_LOCATION)
		elif title == "checkbox_unchecked":
			os.system("mkdir -p " + CONFIG_LOCATION)		
			os.system("touch " + FLAG_LOCATION)		


if __name__ == "__main__":
	MintWelcome()	
	gtk.main()

